@@ -8,14 +8,18 @@ from calibre.devices.kindle.apnx import APNXBuilder
 Device driver for Amazon's Kindle
 '''
 
-import os, re, json, hashlib, errno
+import errno
+import hashlib
+import json
+import os
+import re
 
+from calibre import fsync, prints, strftime
 from calibre.constants import DEBUG, filesystem_encoding
-from calibre.utils.date import utcfromtimestamp
 from calibre.devices.interface import OpenPopupMessage
 from calibre.devices.kindle.bookmark import Bookmark
 from calibre.devices.usbms.driver import USBMS
-from calibre import strftime, fsync, prints
+from calibre.utils.date import utcfromtimestamp
 from polyglot.builtins import as_bytes, as_unicode
 
 '''
@@ -292,8 +296,8 @@ class KINDLE(USBMS):
         return ka_soup
 
     def add_annotation_to_library(self, db, db_id, annotation):
-        from calibre.ebooks.metadata import MetaInformation
         from calibre.ebooks.BeautifulSoup import prettify
+        from calibre.ebooks.metadata import MetaInformation
 
         bm = annotation
         ignore_tags = {'Catalog', 'Clippings'}
@@ -498,7 +502,7 @@ class KINDLE2(KINDLE):
         return os.path.join(self._main_prefix, 'system', 'thumbnails')
 
     def thumbpath_from_filepath(self, filepath):
-        from calibre.ebooks.metadata.kfx import (CONTAINER_MAGIC, read_book_key_kfx)
+        from calibre.ebooks.metadata.kfx import CONTAINER_MAGIC, read_book_key_kfx
         from calibre.ebooks.mobi.reader.headers import MetadataHeader
         from calibre.utils.logging import default_log
         thumb_dir = self.amazon_system_thumbnails_dir()
