@@ -6,16 +6,18 @@ __docformat__ = 'restructuredtext en'
 Command line interface to conversion sub-system
 '''
 
-import sys, os, numbers
-from optparse import OptionGroup, Option
+import numbers
+import os
+import sys
 from collections import OrderedDict
+from optparse import Option, OptionGroup
 
-from calibre.utils.config import OptionParser
-from calibre.utils.logging import Log
-from calibre.customize.conversion import OptionRecommendation
 from calibre import patheq
+from calibre.customize.conversion import OptionRecommendation
 from calibre.ebooks.conversion import ConversionUserFeedBack
+from calibre.utils.config import OptionParser
 from calibre.utils.localization import localize_user_manual_link
+from calibre.utils.logging import Log
 from polyglot.builtins import iteritems
 
 USAGE = '%prog ' + _('''\
@@ -87,7 +89,7 @@ def option_recommendation_to_cli_option(add_option, rec):
     switches.append('--'+opt.long_switch)
     attrs = dict(dest=opt.name, help=opt.help,
                      choices=opt.choices, default=rec.recommended_value)
-    if isinstance(rec.recommended_value, type(True)):
+    if isinstance(rec.recommended_value, bool):
         attrs['action'] = 'store_false' if rec.recommended_value else \
                           'store_true'
     else:
@@ -101,7 +103,7 @@ def option_recommendation_to_cli_option(add_option, rec):
         attrs.pop('type', '')
     if opt.name == 'read_metadata_from_opf':
         switches.append('--from-opf')
-    if opt.name == 'transform_css_rules':
+    elif opt.name == 'transform_css_rules':
         attrs['help'] = _(
             'Path to a file containing rules to transform the CSS styles'
             ' in this book. The easiest way to create such a file is to'
@@ -110,6 +112,15 @@ def option_recommendation_to_cli_option(add_option, rec):
             ' dialog. Once you create the rules, you can use the "Export" button'
             ' to save them to a file.'
         )
+    elif opt.name == 'transform_html_rules':
+        attrs['help'] = _(
+            'Path to a file containing rules to transform the HTML'
+            ' in this book. The easiest way to create such a file is to'
+            ' use the wizard for creating rules in the calibre GUI. Access'
+            ' it in the "Look & feel->Transform HTML" section of the conversion'
+            ' dialog. Once you create the rules, you can use the "Export" button'
+            ' to save them to a file.'
+        )
     if opt.name in DEFAULT_TRUE_OPTIONS and rec.recommended_value is True:
         switches = ['--disable-'+opt.long_switch]
     add_option(Option(*switches, **attrs))
@@ -192,7 +203,7 @@ def add_pipeline_options(parser, plumber):
                       'font_size_mapping', 'embed_font_family',
                       'subset_embedded_fonts', 'embed_all_fonts',
                       'line_height', 'minimum_line_height',
-                      'linearize_tables',
+                      'linearize_tables', 'transform_html_rules',
                       'extra_css', 'filter_css', 'transform_css_rules', 'expand_css',
                       'smarten_punctuation', 'unsmarten_punctuation',
                       'margin_top', 'margin_left', 'margin_right',
@@ -288,7 +299,7 @@ class ProgressBar:
 
 def create_option_parser(args, log):
     if '--version' in args:
-        from calibre.constants import __appname__, __version__, __author__
+        from calibre.constants import __appname__, __author__, __version__
         log(os.path.basename(args[0]), '('+__appname__, __version__+')')
         log('Created by:', __author__)
         raise SystemExit(0)
@@ -338,7 +349,8 @@ def escape_sr_pattern(exp):
 
 
 def read_sr_patterns(path, log=None):
-    import json, re
+    import json
+    import re
     pats = []
     with open(path, 'rb') as f:
         lines = f.read().decode('utf-8').splitlines()
@@ -388,6 +400,17 @@ def main(args=sys.argv):
                     log.error(title)
                     log.error(msg)
                     return 1
+    if opts.transform_html_rules:
+        from calibre.ebooks.html_transform_rules import import_rules, validate_rule
+        with open(opts.transform_html_rules, 'rb') as tcr:
+            opts.transform_html_rules = rules = list(import_rules(tcr.read()))
+            for rule in rules:
+                title, msg = validate_rule(rule)
+                if title and msg:
+                    log.error('Failed to parse HTML transform rules')
+                    log.error(title)
+                    log.error(msg)
+                    return 1
 
     recommendations = [(n.dest, getattr(opts, n.dest),
                         OptionRecommendation.HIGH)
