@@ -1,4 +1,3 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
 '''
 HTML-TOC-adding transform.
 '''
@@ -6,10 +5,8 @@ HTML-TOC-adding transform.
 __license__   = 'GPL v3'
 __copyright__ = '2008, Marshall T. Vandegrift <llasram@gmail.com>'
 
-from calibre.ebooks.oeb.base import XML, XHTML, XHTML_NS
-from calibre.ebooks.oeb.base import XHTML_MIME, CSS_MIME
-from calibre.ebooks.oeb.base import element, XPath
-from polyglot.builtins import unicode_type
+from calibre.ebooks.oeb.base import CSS_MIME, XHTML, XHTML_MIME, XHTML_NS, XML, XPath, element
+from calibre.utils.localization import __
 
 __all__ = ['HTMLTOCAdder']
 
@@ -46,7 +43,7 @@ body > .calibre_toc_block {
     }
 
 
-class HTMLTOCAdder(object):
+class HTMLTOCAdder:
 
     def __init__(self, title=None, style='nested', position='end'):
         self.title = title
@@ -95,7 +92,7 @@ class HTMLTOCAdder(object):
             style = 'nested'
         id, css_href = oeb.manifest.generate('tocstyle', 'tocstyle.css')
         oeb.manifest.add(id, css_href, CSS_MIME, data=STYLE_CSS[style])
-        language = unicode_type(oeb.metadata.language[0])
+        language = str(oeb.metadata.language[0])
         contents = element(None, XHTML('html'), nsmap={None: XHTML_NS},
                            attrib={XML('lang'): language})
         head = element(contents, XHTML('head'))
