@@ -5,9 +5,7 @@ __license__   = 'GPL v3'
 __copyright__ = '2008, Kovid Goyal kovid@kovidgoyal.net'
 __docformat__ = 'restructuredtext en'
 
-from PyQt5.Qt import (
-    QDialog, Qt, QIcon, QVBoxLayout, QHBoxLayout, QLabel, QCheckBox, QDialogButtonBox
-)
+from qt.core import QCheckBox, QDialog, QDialogButtonBox, QHBoxLayout, QIcon, QLabel, Qt, QVBoxLayout
 
 from calibre import confirm_config_name
 from calibre.gui2 import dynamic
@@ -20,17 +18,18 @@ class Dialog(QDialog):
                  title=None, confirm_msg=None, show_cancel_button=True, extra_button=None):
         QDialog.__init__(self, parent)
         self.setWindowTitle(title or _("Are you sure?"))
-        self.setWindowIcon(QIcon(I(icon)))
+        self.setWindowIcon(QIcon.ic(icon))
         self.l = l = QVBoxLayout(self)
         self.h = h = QHBoxLayout()
         l.addLayout(h)
 
         self.icon_widget = Icon(self)
-        self.icon_widget.set_icon(QIcon(I(icon)))
+        self.icon_widget.set_icon(QIcon.ic(icon))
 
         self.msg = m = QLabel(self)
         m.setOpenExternalLinks(True)
         m.setMinimumWidth(350), m.setWordWrap(True), m.setObjectName("msg")
+        m.setMaximumHeight(400)
         m.setText(msg)
 
         h.addWidget(self.icon_widget), h.addSpacing(10), h.addWidget(m)
@@ -73,10 +72,12 @@ def confirm(msg, name, parent=None, pixmap='dialog_warning.png', title=None,
         show_cancel_button=True, confirm_msg=None, config_set=None, extra_button=None):
     config_set = config_set or dynamic
     if not config_set.get(confirm_config_name(name), True):
+        if extra_button:
+            return True, False
         return True
     d = Dialog(msg, name, parent, config_set=config_set, icon=pixmap, extra_button=extra_button,
                title=title, confirm_msg=confirm_msg, show_cancel_button=show_cancel_button)
-    ret = d.exec_() == QDialog.DialogCode.Accepted
+    ret = d.exec() == QDialog.DialogCode.Accepted
     if extra_button:
         ret = ret, d.extra_button_clicked
     return ret
