@@ -10,9 +10,23 @@ import copy
 import re
 from enum import Enum
 from functools import partial
+
 from qt.core import (
-    QCheckBox, QColor, QComboBox, QDialog, QDialogButtonBox, QGridLayout, QGroupBox,
-    QHBoxLayout, QIcon, QLabel, QLineEdit, QRadioButton, QSpinBox, Qt, QVBoxLayout,
+    QCheckBox,
+    QColor,
+    QComboBox,
+    QDialog,
+    QDialogButtonBox,
+    QGridLayout,
+    QGroupBox,
+    QHBoxLayout,
+    QIcon,
+    QLabel,
+    QLineEdit,
+    QRadioButton,
+    QSpinBox,
+    Qt,
+    QVBoxLayout,
     QWidget,
 )
 
@@ -323,10 +337,16 @@ class CreateCustomColumn(QDialog):
         self.use_decorations = ud = QCheckBox(_("Show &checkmarks"), self)
         ud.setToolTip(_("Show check marks in the GUI. Values of 'yes', 'checked', and 'true'\n"
             "will show a green check. Values of 'no', 'unchecked', and 'false' will show a red X.\n"
-            "Everything else will show nothing."))
+            "Everything else will show nothing. Note that the values of 'true' and 'false' don't\n"
+            "follow calibre's language settings and are always in English."))
         h.addWidget(ud)
         self.is_names = ins = QCheckBox(_("Contains names"), self)
-        ins.setToolTip(_("Check this box if this column contains names, like the authors column."))
+        ins.setToolTip('<p>' + _('Check this box if this column contains names, '
+             'like the authors column. If checked, the item separator will be an ampersand '
+             '(&) instead of a comma (,), sorting will be done using a computed value '
+             'that respects the author sort tweaks (for example converting "Firstname '
+             'Lastname" into "Lastname, Firstname"), and item order will be '
+             'preserved.')+'</p>')
         h.addWidget(ins)
         add_row(_("&Column type:"), h)
 
@@ -396,16 +416,20 @@ class CreateCustomColumn(QDialog):
                 ('side', _('Show heading to the side of the text'))
         ):
             ct.addItem(text, k)
-        ct.setToolTip(_('Choose whether or not the column heading is shown in the Book\n'
-                        'details panel and, if shown, where'))
-        self.comments_heading_position_label = add_row(_('Column heading:'), ct)
+        ct.setToolTip('<p>' +
+                      _('Choose whether or not the column heading is shown in the Book '
+                      'details panel and, if shown, where. Setting this to '
+                      "'Show heading to the side of the text' moves the information "
+                      "from dislayed with other comments to displayed with the "
+                      "non-comments columns.") + '</p>')
+        self.comments_heading_position_label = add_row(_('Heading position:'), ct)
 
         self.comments_type = ct = QComboBox(self)
         for k, text in (
                 ('html', 'HTML'),
                 ('short-text', _('Short text, like a title')),
                 ('long-text', _('Plain text')),
-                ('markdown', _('Plain text formatted using markdown'))
+                ('markdown', _('Plain text formatted using Markdown'))
         ):
             ct.addItem(text, k)
         ct.setToolTip(_('Choose how the data in this column is interpreted.\n'
@@ -457,9 +481,9 @@ class CreateCustomColumn(QDialog):
         l.addStretch()
         add_row(None, l)
         l = QHBoxLayout()
-        self.composite_in_comments_box = cmc = QCheckBox(_("Show with comments in book details"))
+        self.composite_in_comments_box = cmc = QCheckBox(_("Show with comments in Book details"))
         cmc.setToolTip('<p>' + _('If you check this box then the column contents '
-                                 'will show in the Comments section in book details. '
+                                 'will show in the Comments section in the Book details. '
                                  'You can indicate whether not to have a header or '
                                  'to put a header above the column. If you want a '
                                  "header beside the data, don't check this box. "
