@@ -5,19 +5,18 @@ __license__   = 'GPL v3'
 __copyright__ = '2009, Kovid Goyal <kovid@kovidgoyal.net>'
 __docformat__ = 'restructuredtext en'
 
-import re, time
+import re
+import time
 from functools import partial
 
+from qt.core import QAction, QApplication, QComboBox, QCompleter, QDialog, QEvent, QIcon, QKeyEvent, QKeySequence, QLineEdit, Qt, QTimer, pyqtSignal, pyqtSlot
 
-from qt.core import (
-    QComboBox, Qt, QLineEdit, pyqtSlot, QDialog, QEvent,
-    pyqtSignal, QCompleter, QAction, QKeySequence, QTimer,
-    QIcon, QApplication, QKeyEvent)
-
-from calibre.gui2 import config, question_dialog, gprefs, QT_HIDDEN_CLEAR_ACTION
+from calibre.gui2 import QT_HIDDEN_CLEAR_ACTION, config, gprefs, question_dialog
 from calibre.gui2.dialogs.saved_search_editor import SavedSearchEditor
 from calibre.gui2.dialogs.search import SearchDialog
+from calibre.gui2.widgets import stylesheet_for_lineedit
 from calibre.utils.icu import primary_sort_key
+from calibre.utils.localization import pgettext
 from polyglot.builtins import native_string_type, string_or_bytes
 
 
@@ -174,7 +173,7 @@ class SearchBox2(QComboBox):  # {{{
 
     def normalize_state(self):
         self.setToolTip(self.tool_tip_text)
-        self.line_edit.setStyleSheet('')
+        self.setStyleSheet('')
         self.show_parse_error_action(False)
 
     def text(self):
@@ -194,11 +193,9 @@ class SearchBox2(QComboBox):  # {{{
         self.setFocus(Qt.FocusReason.OtherFocusReason)
 
     def show_parse_error_action(self, to_show, tooltip=''):
-        try:
+        if self.parse_error_action is not None:
             self.parse_error_action.setVisible(to_show)
             self.parse_error_action.setToolTip(tooltip)
-        except Exception:
-            pass
 
     def search_done(self, ok):
         if isinstance(ok, string_or_bytes):
@@ -206,9 +203,14 @@ class SearchBox2(QComboBox):  # {{{
             self.show_parse_error_action(True, tooltip=ok)
             ok = False
         if not str(self.currentText()).strip():
+            self.setStyleSheet('')
             self.clear(emit_search=False)
             return
         self._in_a_search = ok
+        if self.parse_error_action is not None and not ok:
+            self.setStyleSheet(stylesheet_for_lineedit(bool(ok), 'QComboBox'))
+        else:
+            self.setStyleSheet('')
 
     # Comes from the lineEdit control
     def key_pressed(self, event):
@@ -397,7 +399,7 @@ class SearchBoxMixin:  # {{{
         else:
             b.setIcon(QIcon.ic('highlight_only_off.png'))
             if gprefs['search_tool_bar_shows_text']:
-                b.setText(_('Highlight'))
+                b.setText(pgettext('mark books matching search result instead of filtering them', 'Highlight'))
                 b.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonTextBesideIcon)
             else:
                 b.setText(None)
