@@ -1,34 +1,35 @@
 #!/usr/bin/env python
-# vim:fileencoding=utf-8
 
 
 __license__ = 'GPL v3'
 __copyright__ = '2014, Kovid Goyal <kovid at kovidgoyal.net>'
 
-import re, io, weakref, sys
+import io
+import re
+import sys
+import weakref
 
-from PyQt5.Qt import (
-    pyqtSignal, QVBoxLayout, QHBoxLayout, QPlainTextEdit, QLabel, QFontMetrics,
-    QSize, Qt, QApplication, QIcon, QDialogButtonBox)
+from qt.core import QApplication, QDialogButtonBox, QFontMetrics, QHBoxLayout, QIcon, QLabel, QPlainTextEdit, QSize, Qt, QVBoxLayout, pyqtSignal
 
-from calibre.ebooks.oeb.polish.utils import apply_func_to_match_groups, apply_func_to_html_text
+from calibre.ebooks.oeb.polish.utils import apply_func_to_html_text, apply_func_to_match_groups
 from calibre.gui2 import error_dialog
 from calibre.gui2.complete2 import EditWithComplete
 from calibre.gui2.tweak_book import dictionaries
-from calibre.gui2.tweak_book.widgets import Dialog
 from calibre.gui2.tweak_book.editor.text import TextEdit
+from calibre.gui2.tweak_book.widgets import Dialog
 from calibre.utils.config import JSONConfig
-from calibre.utils.icu import capitalize, upper, lower, swapcase
-from calibre.utils.titlecase import titlecase
+from calibre.utils.icu import capitalize, lower, swapcase, upper
 from calibre.utils.localization import localize_user_manual_link
-from polyglot.builtins import iteritems, unicode_type
+from calibre.utils.resources import get_path as P
+from calibre.utils.titlecase import titlecase
+from polyglot.builtins import iteritems
 from polyglot.io import PolyglotStringIO
 
 user_functions = JSONConfig('editor-search-replace-functions')
 
 
 def compile_code(src, name='<string>'):
-    if not isinstance(src, unicode_type):
+    if not isinstance(src, str):
         match = re.search(br'coding[:=]\s*([-\w.]+)', src[:200])
         enc = match.group(1).decode('utf-8') if match else 'utf-8'
         src = src.decode(enc)
@@ -45,7 +46,7 @@ def compile_code(src, name='<string>'):
     return namespace
 
 
-class Function(object):
+class Function:
 
     def __init__(self, name, source=None, func=None):
         self._source = source
@@ -119,7 +120,7 @@ class DebugOutput(Dialog):
         self.bb.setStandardButtons(QDialogButtonBox.StandardButton.Close)
         self.cb = b = self.bb.addButton(_('&Copy to clipboard'), QDialogButtonBox.ButtonRole.ActionRole)
         b.clicked.connect(self.copy_to_clipboard)
-        b.setIcon(QIcon(I('edit-copy.png')))
+        b.setIcon(QIcon.ic('edit-copy.png'))
 
     def show_log(self, name, text):
         if isinstance(text, bytes):
@@ -128,7 +129,7 @@ class DebugOutput(Dialog):
         self.text.setPlainText(self.windowTitle() + '\n\n' + text)
         self.log_text = text
         self.show()
-        self.raise_()
+        self.raise_and_focus()
 
     def sizeHint(self):
         fm = QFontMetrics(self.text.font())
@@ -211,7 +212,7 @@ class FunctionBox(EditWithComplete):
             menu.addSeparator()
             menu.addAction(_('Save current search'), self.save_search.emit)
             menu.addAction(_('Show saved searches'), self.show_saved_searches.emit)
-        menu.exec_(event.globalPos())
+        menu.exec(event.globalPos())
 
 
 class FunctionEditor(Dialog):
@@ -373,5 +374,5 @@ def replace_swapcase_ignore_tags(match, number, file_name, metadata, dictionarie
 
 if __name__ == '__main__':
     app = QApplication([])
-    FunctionEditor().exec_()
+    FunctionEditor().exec()
     del app
