@@ -4,27 +4,76 @@
 
 import sys
 import textwrap
+from functools import lru_cache
+
 from qt.core import (
-    QAbstractItemView, QApplication, QCheckBox, QComboBox, QDialog, QDialogButtonBox,
-    QFormLayout, QHBoxLayout, QIcon, QLabel, QLineEdit, QListWidget, QListWidgetItem,
-    QPushButton, QSize, Qt, QTimer, QUrl, QVBoxLayout, QWidget, pyqtSignal
-)
-from qt.webengine import (
-    QWebEnginePage, QWebEngineProfile, QWebEngineScript, QWebEngineView
+    QAbstractItemView,
+    QApplication,
+    QCheckBox,
+    QComboBox,
+    QDateTime,
+    QDialog,
+    QDialogButtonBox,
+    QFormLayout,
+    QHBoxLayout,
+    QIcon,
+    QLabel,
+    QLineEdit,
+    QListWidget,
+    QListWidgetItem,
+    QNetworkCookie,
+    QPalette,
+    QPushButton,
+    QSize,
+    Qt,
+    QTimer,
+    QUrl,
+    QVBoxLayout,
+    QWidget,
+    pyqtSignal,
 )
+from qt.webengine import QWebEnginePage, QWebEngineProfile, QWebEngineScript, QWebEngineView
 
 from calibre import prints, random_user_agent
+from calibre.ebooks.metadata.sources.search_engines import google_consent_cookies
 from calibre.gui2 import error_dialog
 from calibre.gui2.viewer.web_view import apply_font_settings, vprefs
 from calibre.gui2.widgets2 import Dialog
-from calibre.utils.webengine import (
-    create_script, insert_scripts, secure_webengine, setup_profile
-)
+from calibre.utils.localization import _, canonicalize_lang, get_lang, lang_as_iso639_1
+from calibre.utils.resources import get_path as P
+from calibre.utils.webengine import create_script, insert_scripts, secure_webengine, setup_profile
+
+
+@lru_cache
+def lookup_lang():
+    ans = canonicalize_lang(get_lang())
+    if ans:
+        ans = lang_as_iso639_1(ans) or ans
+    return ans
+
+
+special_processors = {}
+
+
+def special_processor(func):
+    special_processors[func.__name__] = func
+    return func
+
+
+@special_processor
+def google_dictionary(word):
+    ans = f'https://www.google.com/search?q=define:{word}'
+    lang = lookup_lang()
+    if lang:
+        ans += f'#dobc={lang}'
+    return ans
+
 
 vprefs.defaults['lookup_locations'] = [
     {
         'name': 'Google dictionary',
         'url': 'https://www.google.com/search?q=define:{word}',
+        'special_processor': 'google_dictionary',
         'langs': [],
     },
 
@@ -196,6 +245,17 @@ def create_profile():
         insert_scripts(ans, create_script('lookup.js', js, injection_point=QWebEngineScript.InjectionPoint.DocumentCreation))
         s = ans.settings()
         s.setDefaultTextEncoding('utf-8')
+        cs = ans.cookieStore()
+        for c in google_consent_cookies():
+            cookie = QNetworkCookie()
+            cookie.setName(c['name'].encode())
+            cookie.setValue(c['value'].encode())
+            cookie.setDomain(c['domain'])
+            cookie.setPath(c['path'])
+            cookie.setSecure(False)
+            cookie.setHttpOnly(False)
+            cookie.setExpirationDate(QDateTime())
+            cs.setCookie(cookie)
         create_profile.ans = ans
     return ans
 
@@ -244,6 +304,18 @@ def set_sync_override(allowed):
         li.set_sync_override(allowed)
 
 
+def blank_html():
+    msg = _('Double click on a word in the book\'s text to look it up.')
+    html = '<p>' + msg
+    app = QApplication.instance()
+    if app.is_dark_theme:
+        pal = app.palette()
+        bg = pal.color(QPalette.ColorRole.Base).name()
+        fg = pal.color(QPalette.ColorRole.Text).name()
+        html = f'<style> * {{ color: {fg}; background-color: {bg} }} </style>' + html
+    return html
+
+
 class Lookup(QWidget):
 
     def __init__(self, parent):
@@ -269,8 +341,7 @@ class Lookup(QWidget):
         l.addWidget(self.view)
         self.populate_sources()
         self.source_box.currentIndexChanged.connect(self.source_changed)
-        self.view.setHtml('<p>' + _('Double click on a word in the book\'s text'
-            ' to look it up.'))
+        self.view.setHtml(blank_html())
         self.add_button = b = QPushButton(QIcon.ic('plus.png'), _('Add sources'))
         b.setToolTip(_('Add more sources at which to lookup words'))
         b.clicked.connect(self.add_sources)
@@ -358,6 +429,12 @@ class Lookup(QWidget):
         if idx > -1:
             return self.source_box.itemData(idx)['url']
 
+    @property
+    def special_processor(self):
+        idx = self.source_box.currentIndex()
+        if idx > -1:
+            return special_processors.get(self.source_box.itemData(idx).get('special_processor'))
+
     @property
     def query_is_up_to_date(self):
         query = self.selected_text or self.current_query
@@ -376,7 +453,12 @@ class Lookup(QWidget):
         if not self.is_visible or not query:
             return
         self.current_source = self.url_template
-        url = self.current_source.format(word=query)
+        sp = self.special_processor
+        if sp is None:
+            url = self.current_source.format(word=query)
+        else:
+            url = sp(query)
+
         self.view.load(QUrl(url))
         self.current_query = query
         self.update_refresh_button_status()
